@@ -99,7 +99,9 @@ class CidClient:
             aggregate_crate += self._fetch_instance_crate(crate)["payload"]["crates"]
 
         # Pull down and create the tree associated with the craft
-        the_tree = self._fetch_instance_tree(craft["frame_id"])
+        if len(craft["frame_ids"]) > 1:
+            raise ValueError("The Python client does not support multiple frames at this time")
+        the_tree = self._fetch_instance_tree(craft["frame_ids"][0])
 
         return Craft(craft["name"], craft["id"], aggregate_crate, the_tree,
                      {"component_resync_query": self._component_resync_query,
